#
# spec file for package ghostscript
#
# Copyright (c) 2018 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ghostscript
BuildRequires:  cups-devel
# dbus-1-devel is needed for "configure --enable-dbus" (see below):
BuildRequires:  dbus-1-devel
BuildRequires:  freetype2-devel
BuildRequires:  libexpat-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  xorg-x11-devel
BuildRequires:  xorg-x11-fonts
BuildRequires:  zlib-devel
Summary:        The Ghostscript interpreter for PostScript and PDF
License:        AGPL-3.0
Group:          System/Libraries
Url:            http://www.ghostscript.com/
# Special version needed for Ghostscript release candidates (e.g. "Version: 9.14pre15rc1" for 9.15rc1).
# Version 9.15rc1 would be newer than 9.15 (run "zypper vcmp 9.15rc1 9.15") because the rpmvercmp algorithm
# would treat 9.15rc1 as 9.15.rc.1 (alphabetic and numeric sections get separated into different elements)
# and 9.15.rc.1 is newer than 9.15 (it has one more element in the list while previous elements are equal)
# so that we use an alphabetic prefix 'pre' to make it older than 9.15 (numbers are considered newer than letters).
# But only with the alphabetic prefix "9.pre15rc1" would be older than the previous version number "9.14"
# because rpmvercmp would treat 9.pre15rc1 as 9.pre.15.rc1 and letters are older than numbers
# so that we keep additionally the previous version number to upgrade from the previous version:
#Version:        9.14pre15rc2
# Normal version for Ghostscript releases is the upstream version:
Version:        9.15
Release:        14.6.1
# tarball_version is used below to specify the directory via "setup -n":
# Special tarball_version needed for Ghostscript release candidates e.g. "define tarball_version 9.15rc1".
# For Ghostscript releases tarball_version and version are the same (i.e. the upstream version):
%define tarball_version %{version}
#define tarball_version 9.15rc2
# built_version is used below in the install and files sections:
# Separated built_version needed in case of Ghostscript release candidates e.g. "define built_version 9.15".
# For Ghostscript releases built_version and version are the same (i.e. the upstream version):
%define built_version %{version}
#define built_version 9.15
# Source0...Source9 is for sources from upstream:
# Special URLs for Ghostscript release candidates:
# URL for Source0: http://www.ghostscript.com/~chrisl/ghostscript-9.15rc2.tar.gz
# URL for MD5 checksums: http://www.ghostscript.com/~chrisl/MD5SUMS or http://www.ghostscript.com/~chrisl/MD5SUM
# MD5 checksum for Source0: 20bffacff52552aa1c430fe64403fb68
#Source0:        http://www.ghostscript.com/~chrisl/ghostscript-9.15rc2.tar.gz
# Normal URLs for Ghostscript releases:
# URL for Source0: http://downloads.ghostscript.com/public/ghostscript-9.15.tar.gz
# URL for MD5 checksums: http://downloads.ghostscript.com/public/MD5SUMS
# MD5 checksum for Source0: 5a78ab0990ff6ec3a103576bc8777c46
Source0:        http://downloads.ghostscript.com/public/ghostscript-%{version}.tar.gz
# Patch0...Patch9 is for patches from upstream:
# Patch0 fix-mutex-crash.patch: fix crash in mutex (bsc#963017)
# (ghostscript bug #695862)
Patch0:         fix-mutex-crash.patch
#
# Source10...Source99 is for sources from SUSE which are intended for upstream:
#
# Patch10...Patch99 is for patches from SUSE which are intended for upstream:
# Patch10 ppc64le-support.patch (initially from IBM)
# fixes endianness in lcms (the Little-CMS library)
# the current patch is a remainder of the previous patch
# lcms2 has been fixed upstream not working lcms has not been fixed:
Patch10:        ppc64le-support.patch
# Patch11 CVE-2015-3228.patch fixes out of bound read/write cause by integer overflow
# in gsmalloc.c (see https://bugzilla.opensuse.org/show_bug.cgi?id=939342):
Patch11:        CVE-2015-3228.patch
# Have filenameforall and getenv honor SAFER
# https://bugzilla.suse.com/show_bug.cgi?id=1001951
Patch12:        CVE-2013-5653.patch
# Reference count device icc profile when copying a device
# https://bugzilla.suse.com/show_bug.cgi?id=1001951
Patch13:        CVE-2016-7978.patch
# Bug #697190 ".initialize_dsc_parser doesn't validate the parameter is a dict type before using it."
# https://bugzilla.suse.com/show_bug.cgi?id=1001951
Patch14:        CVE-2016-7979.patch
# Patch15 CVE-2016-8602.patch fixes a NULL dereference in .sethalftone5
# see http://bugs.ghostscript.com/show_bug.cgi?id=697203
# and https://bugzilla.suse.com/show_bug.cgi?id=1004237
Patch15:        CVE-2016-8602.patch
# PATCH-FIX-UPSTREAM 0001-Fix-locksafe.patch boo#1006592 -- Fix for regression introduced in CVE-2013-5653.patch
Patch16:        0001-Fix-locksafe.patch
# Patch17 CVE-2017-8291.patch fixes a type confusion in .rsdparams and .eqproc
# see https://bugs.ghostscript.com/show_bug.cgi?id=697808
# and https://bugzilla.suse.com/show_bug.cgi?id=1036453
Patch17:        CVE-2017-8291.patch
# Patch18 CVE-2016-9601.patch fixes an integer overflow in jbig2_image_new
# see https://bugs.ghostscript.com/show_bug.cgi?id=697457
# and https://bugzilla.suse.com/show_bug.cgi?id=1018128
Patch18:        CVE-2016-9601.patch
# Patch19 CVE-2016-10220.patch fixes a NULL pointer dereference in gx_device_finalize
# see https://bugs.ghostscript.com/show_bug.cgi?id=697450
# and https://bugzilla.suse.com/show_bug.cgi?id=1032120
Patch19:        CVE-2016-10220.patch
# Patch20 CVE-2017-5951.patch fixes a NULL pointer dereference in ref_stack_index
# see https://bugs.ghostscript.com/show_bug.cgi?id=697548
# and https://bugzilla.suse.com/show_bug.cgi?id=1032114
Patch20:        CVE-2017-5951.patch
# Patch21 CVE-2017-7207.patch fixes a NULL pointer dereference in mem_get_bits_rectangle
# see https://bugs.ghostscript.com/show_bug.cgi?id=697676
# and https://bugzilla.suse.com/show_bug.cgi?id=1030263
Patch21:        CVE-2017-7207.patch
# Patch22 fixes NULL pointer dereference in the jbig2_huffman_get function
# see https://bugs.ghostscript.com/show_bug.cgi?id=697934
# and https://bugzilla.suse.com/show_bug.cgi?id=1040643
Patch22:        CVE-2017-9216.patch
# Patch23 fixes DoS in fill_threshhold_buffer function
# see https://bugzilla.suse.com/show_bug.cgi?id=1032230
# and https://bugs.ghostscript.com/show_bug.cgi?id=697459
Patch23:        CVE-2016-10317.patch
# Patch24 fixes DoS in Ins_IP function in base/ttinterp.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1050891
# and https://bugs.ghostscript.com/show_bug.cgi?id=698026
Patch24:        CVE-2017-9612.patch
# Patch25 fixes heap-based buffer over-read in Ins_MDRP in base/ttinterp.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1050889
# and http://bugs.ghostscript.com/show_bug.cgi?id=698055
Patch25:        CVE-2017-9726.patch
# Patch26 fixes DoS in gx_ttfReader__Read function in base/gxttfb.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1050888
# and http://bugs.ghostscript.com/show_bug.cgi?id=698056
Patch26:        CVE-2017-9727.patch
# Patch27 fixes DoS in Ins_JMPR function in base/ttinterp.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1050887
# and https://bugs.ghostscript.com/show_bug.cgi?id=698063
Patch27:        CVE-2017-9739.patch
# Patch28 fixes Out of bounds read in igc_reloc_struct_ptr()
# see https://bugzilla.suse.com/show_bug.cgi?id=1051184
Patch28:        CVE-2017-11714.patch
# Patch29 fixes DoS in intersect() function in base/gxfill.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1032138
# and https://bugs.ghostscript.com/show_bug.cgi?id=697453
Patch29:        CVE-2016-10219.patch
# Patch30 fixes heap-based buffer overflow in gs_alloc_ref_array
# see https://bugzilla.suse.com/show_bug.cgi?id=1050879
# and https://bugs.ghostscript.com/show_bug.cgi?id=697985
Patch30:        CVE-2017-9835.patch
# Patch31 fixes stack-based buffer overflow in gdevpdts.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1090099
# and https://bugs.ghostscript.com/show_bug.cgi?id=699255
# and http://git.ghostscript.com/?p=ghostpdl.git;a=commit;h=39b1e54b2968620723bf32e96764c88797714879
Patch31:        CVE-2018-10194.patch

# Source100...Source999 is for sources from SUSE which are not intended for upstream:
#
# Patch100...Patch999 is for patches from SUSE which are not intended for upstream:
#
# RPM dependencies:
# Additional RPM Provides of the ghostscript-library packages in openSUSE 11.4 from
# "rpm -q --provides ghostscript-library" and "rpm -q --provides ghostscript-x11":
#   ghostscript
#   gs
#   gs_lib
#   pstoraster
#   ghostscript_any
#   ghostscript-serv
#   gs_x11
#   ghostscript_x11
#   ghostscript-mini
# Which of those are actually used in openSUSE:Factory (dated 22 Feb. 2012):
#   ghostscript
#   gs
#   gs_lib
#   ghostscript_any
#   ghostscript_x11
#   ghostscript-mini
# Which other packages need those in openSUSE:Factory (dated 22 Feb. 2012):
#   blocxx-doc       BuildRequires ghostscript
#   iproute2         BuildRequires ghostscript
#   gle-graphics     Requires      ghostscript
#   webdot           Requires      ghostscript
#   ddd              BuildRequires ghostscript_any
#   emacs-auctex     BuildRequires ghostscript_any
#   kernel-docs      BuildRequires ghostscript_any
#   texlive-bin      BuildRequires ghostscript_any
#   cups             Requires      ghostscript_any
#   html2ps          Requires      ghostscript_any
#   latex2html       Requires      ghostscript_any
#   pstoedit         Requires      ghostscript_any
#   ghostview        Requires      ghostscript_x11
#   gv               Requires      ghostscript_x11
#   texlive-bin      Requires      ghostscript_x11
#   klatexformula    BuildRequires gs and Requires gs
#   capi4hylafax     Requires      gs_lib
#   hylafax          Requires      gs_lib
#   graphviz-plugins BuildRequires ghostscript-mini
# Provide the additional RPM Provides of the ghostscript-library package
# (ghostscript_x11 is provided by the ghostscript-x11 sub-package, see below):
Provides:       ghostscript_any
Provides:       gs
Provides:       gs_lib
# There is a needless requirement for pstoraster in gutenprint up to openSUSE 11.4.
# Satisfy it to be backward compatible with installed gutenprint packages:
Provides:       pstoraster
# Replace any version of the packages ghostscript-library and ghostscript-mini silently.
# The "Obsoletes: ghostscript-mini" is intentionally unversioned because
# this package ghostscript should replace any version of ghostscript-mini.
# There is intentionally no "Provides: ghostscript-mini" here because this
# would cause a conflict when this package ghostscript should be re-replaced
# by ghostscript-library because ghostscript-library conflicts with ghostscript-mini
# so that there would be no easy way back from ghostscript to ghostscript-library.
# Different versions must be explicitly specified in Provides and Obsoletes
# to avoid a RPMLINT warning that the package obsoletes itself
# because an unversioned RPM dependency means "all versions".
# The RPM documentation http://www.rpm.org/max-rpm/s1-rpm-depend-manual-dependencies.html
# and /usr/share/doc/packages/rpm/manual/dependencies (in rpm-4.8.0 in openSUSE 11.4)
# does not show a comparison operator for "not equal" so that two obsoletes are used:
Provides:       ghostscript-library = %{version}
Obsoletes:      ghostscript-library < %{version}
Obsoletes:      ghostscript-library > %{version}
Obsoletes:      ghostscript-mini
# The ghostscript-x11 sub-package requires the exact matching version-release
# of the ghostscript main-package (see below) so that the ghostscript main-package
# should conflict with a non-matching ghostscript-x11 package to make sure
# that the ghostscript main-package is not changed without changing
# the ghostscript-x11 sub-package accordingly.
# The RPM documentation http://www.rpm.org/max-rpm/s1-rpm-depend-manual-dependencies.html
# and /usr/share/doc/packages/rpm/manual/dependencies (in rpm-4.8.0 in openSUSE 11.4)
# does not show a comparison operator for "not equal" so that two conflicts are used:
Conflicts:      ghostscript-x11 < %{version}-%{release}
Conflicts:      ghostscript-x11 > %{version}-%{release}
# When the ghostscript main-package is installed, usually the exact matching
# version-release of the ghostscript-x11 sub-package should be also installed:
Recommends:     ghostscript-x11 = %{version}-%{release}
# When the ghostscript main-package is installed, usually the CUPS filters gstoraster and gstopxl
# should be also installed. Since version 9.10 those CUPS filters are removed from Ghostscript
# and are now provided by the binary RPM sub-package cups-filters-ghostscript
# (see the cups-filters-ghostscript sub-package description).
# No RPM requirement because Ghostscript can be used without those CUPS filters
# and cups-filters-ghostscript is only available for newer openSUSE versions
# (currently since openSUSE 12.2) but in particular not for SLE11:
%if 0%{?suse_version} > 1210
Recommends:     cups-filters-ghostscript
%endif
# Require Ghostscript's fonts because the Ghostscript package provides the
# "Fontmap" file /usr/share/ghostscript/<version>/Resource/Init/Fontmap.GS
# which lists Ghostscript's fonts but the fonts itself are provided in the
# separated packages ghostscript-fonts-std and ghostscript-fonts-other
# (regarding separated packages see /usr/share/ghostscript/<version>/doc/Fonts.htm)
# so that a RPM requirement is needed to make sure that Ghostscript has its fonts:
Requires:       ghostscript-fonts-other
Requires:       ghostscript-fonts-std
# Prerequire /sbin/ldconfig which is used in the traditional bash scriptlets for post/postun:
PreReq:         /sbin/ldconfig
# Install into this non-root directory (required when norootforbuild is used):
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ghostscript is a package of software that provides:

An interpreter for the PostScript language,
with the ability to convert PostScript language files
to many raster formats, view them on displays,
and print them on printers that don't have
PostScript language capability built in.

An interpreter for Portable Document Format (PDF) files,
with the same abilities.

The ability to convert PostScript language files
to PDF (with some limitations) and vice versa.

A set of C procedures (the Ghostscript library)
that implement the graphics and filtering
(data compression / decompression / conversion)
capabilities that appear as primitive operations
in the PostScript language and in PDF.

For information how to use Ghostscript see
/usr/share/ghostscript/%{version}/doc/Use.htm

%package x11
Summary:        X11 library for Ghostscript
Group:          Productivity/Publishing/PS
# Require the exact matching version-release of the ghostscript main-package because
# a non-matching ghostscript main-package may let it fail or even crash (e.g. segfault)
# because all Ghostscript software is built from one same Ghostscript source tar ball
# so that there could be any kind of Ghostscript-internal dependencies.
# The exact matching version-release of the ghostscript main-package is available
# on the same package repository where the ghostscript-x11 sub-package is because
# all are built simulaneously from the same Ghostscript source package:
Requires:       ghostscript = %{version}-%{release}
# Unfortunately ghostscript-library.spec and ghostscript-mini.spec have
# an unversioned "Provides: ghostscript" and for RPM this means that both
# ghostscript-library and ghostscript-mini provide any version of "ghostscript"
# so that any version of ghostscript-library and ghostscript-mini fulfills
# the above versioned requirement which is wrong and therefore an explicit conflicts
# is used here to avoid the mess.
# Above the ghostscript main package "Provides: ghostscript-library = version" so that
# versioned conflicts are needed to avoid a conflict with the ghostscript main package.
# The RPM documentation http://www.rpm.org/max-rpm/s1-rpm-depend-manual-dependencies.html
# and /usr/share/doc/packages/rpm/manual/dependencies (in rpm-4.8.0 in openSUSE 11.4)
# does not show a comparison operator for "not equal" so that two conflicts are used:
Conflicts:      ghostscript-library < %{version}
Conflicts:      ghostscript-library > %{version}
Conflicts:      ghostscript-mini
# In openSUSE:Factory (dated 22 Feb. 2012) ghostview gv and texlive-bin require ghostscript_x11 (see above):
Provides:       ghostscript_x11

%description x11
This package contains the X11 library which is needed
to view PostScript and PDF files with Ghostscript
under the X Window System.

%package devel
Summary:        Development files for Ghostscript
Group:          Development/Libraries/C and C++
Requires:       ghostscript = %{version}
# Unfortunately ghostscript-library.spec and ghostscript-mini.spec have
# an unversioned "Provides: ghostscript" and for RPM this means that both
# ghostscript-library and ghostscript-mini provide any version of "ghostscript"
# so that any version of ghostscript-library and ghostscript-mini fulfills
# the above versioned requirement which is wrong and therefore an explicit conflicts
# is used here to avoid the mess.
# Above the ghostscript main package "Provides: ghostscript-library = version" so that
# versioned conflicts are needed to avoid a conflict with the ghostscript main package.
# The RPM documentation http://www.rpm.org/max-rpm/s1-rpm-depend-manual-dependencies.html
# and /usr/share/doc/packages/rpm/manual/dependencies (in rpm-4.8.0 in openSUSE 11.4)
# does not show a comparison operator for "not equal" so that two conflicts are used:
Conflicts:      ghostscript-library < %{version}
Conflicts:      ghostscript-library > %{version}
Conflicts:      ghostscript-mini
Conflicts:      ghostscript-mini-devel

%description devel
This package contains the development files for Ghostscript.

%prep
# Be quiet when unpacking and
# use a directory name matching Source0 to make it work also for ghostscript-mini:
%setup -q -n ghostscript-%{tarball_version}
# Patch0 fix-mutex-crash.patch: fix crash in mutex (bsc#963017)
# (ghostscript bug #695862)
%patch0 -p1
# Patch10 ppc64le-support.patch (initially from IBM)
# fixes endianness in lcms (the Little-CMS library)
# the current patch is a remainder of the previous patch
# lcms2 has been fixed upstream not working lcms has not been fixed:
%patch10 -p1 -b .ppc64le-support.orig
# Patch11 CVE-2015-3228.patch fixes out of bound read/write cause by integer overflow
# in gsmalloc.c (see https://bugzilla.opensuse.org/show_bug.cgi?id=939342):
%patch11 -b .CVE-2015-3228.orig
# Have filenameforall and getenv honor SAFER
# https://bugzilla.suse.com/show_bug.cgi?id=1001951
%patch12 -p1
# Reference count device icc profile when copying a device
# https://bugzilla.suse.com/show_bug.cgi?id=1001951
%patch13 -p1
# Bug #697190 ".initialize_dsc_parser doesn't validate the parameter is a dict type before using it."
# https://bugzilla.suse.com/show_bug.cgi?id=1001951
%patch14 -p1
# Patch15 CVE-2016-8602.patch fixes a NULL dereference in .sethalftone5
# see http://bugs.ghostscript.com/show_bug.cgi?id=697203
# and https://bugzilla.suse.com/show_bug.cgi?id=1004237
%patch15 -p1 -b CVE-2016-8602.orig
# See https://bugzilla.opensuse.org/show_bug.cgi?id=1006592,
# https://bugzilla.opensuse.org/show_bug.cgi?id=1007816 and
# https://bugs.kde.org/show_bug.cgi?id=371887
%patch16 -p1
# Patch17 CVE-2017-8291.patch fixes a type confusion in .rsdparams and .eqproc
# see https://bugs.ghostscript.com/show_bug.cgi?id=697808
# and https://bugzilla.suse.com/show_bug.cgi?id=1036453
%patch17 -p1
# Patch18 CVE-2016-9601.patch fixes an integer overflow in jbig2_image_new
# see https://bugs.ghostscript.com/show_bug.cgi?id=697457
# and https://bugzilla.suse.com/show_bug.cgi?id=1018128
%patch18 -p1
# Patch19 CVE-2016-10220.patch fixes a NULL pointer dereference in gx_device_finalize
# see https://bugs.ghostscript.com/show_bug.cgi?id=697450
# and https://bugzilla.suse.com/show_bug.cgi?id=1032120
%patch19 -p1
# Patch20 CVE-2017-5951.patch fixes a NULL pointer dereference in ref_stack_index
# see https://bugs.ghostscript.com/show_bug.cgi?id=697548
# and https://bugzilla.suse.com/show_bug.cgi?id=1032114
%patch20 -p1
# Patch21 CVE-2017-7207.patch fixes a NULL pointer dereference in mem_get_bits_rectangle
# see https://bugs.ghostscript.com/show_bug.cgi?id=697676
# and https://bugzilla.suse.com/show_bug.cgi?id=1030263
%patch21 -p1
# Patch22 fixes NULL pointer dereference in the jbig2_huffman_get function
# see https://bugs.ghostscript.com/show_bug.cgi?id=697934
# and https://bugzilla.suse.com/show_bug.cgi?id=1040643
%patch22 -p1
# Patch23 fixes DoS in fill_threshhold_buffer function
# see https://bugzilla.suse.com/show_bug.cgi?id=1032230
# and https://bugs.ghostscript.com/show_bug.cgi?id=697459
%patch23 -p1
# Patch24 fixes DoS in Ins_IP function in base/ttinterp.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1050891
# and https://bugs.ghostscript.com/show_bug.cgi?id=698026
%patch24 -p1
# Patch25 fixes heap-based buffer over-read in Ins_MDRP in base/ttinterp.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1050889
# and http://bugs.ghostscript.com/show_bug.cgi?id=698055
%patch25 -p1
# Patch26 fixes DoS in gx_ttfReader__Read function in base/gxttfb.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1050888
# and http://bugs.ghostscript.com/show_bug.cgi?id=698056
%patch26 -p1
# Patch27 fixes DoS in Ins_JMPR function in base/ttinterp.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1050887
# and https://bugs.ghostscript.com/show_bug.cgi?id=698063
%patch27 -p1
# Patch28 fixes Out of bounds read in igc_reloc_struct_ptr()
# see https://bugzilla.suse.com/show_bug.cgi?id=1051184
%patch28 -p1
# Patch29 fixes DoS in intersect() function in base/gxfill.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1032138
# and https://bugs.ghostscript.com/show_bug.cgi?id=697453
%patch29 -p1
# Patch30 fixes heap-based buffer overflow in gs_alloc_ref_array
# see https://bugzilla.suse.com/show_bug.cgi?id=1050879
# and https://bugs.ghostscript.com/show_bug.cgi?id=697985
%patch30 -p1
# Patch31 fixes stack-based buffer overflow in gdevpdts.c
# see https://bugzilla.suse.com/show_bug.cgi?id=1090099
# and https://bugs.ghostscript.com/show_bug.cgi?id=699255
# and http://git.ghostscript.com/?p=ghostpdl.git;a=commit;h=39b1e54b2968620723bf32e96764c88797714879
%patch31 -b CVE-2018-10194.orig

%build
# Set our preferred architecture-specific flags for the compiler and linker:
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
autoreconf -fi
# --docdir=%%{_defaultdocdir}/%%{name} does not work therefore it is not used.
# --enable-cups and --with-pdftoraster and --with-install-cups
#   (--with-install-cups is new since version 9.04)
#   to make and install cups/filter/gstoraster and cups/filter/gstopxl
#   and related files (gstoraster.convs pxlcolor.ppd pxlmono.ppd).
# --enable-dbus to have colord support in gstoraster, see cups/colord.c (colord is accessed via D-Bus).
# --with-ijs to enable IJS printer driver support (in particular needed by HPIJS).
# --with-drivers=ALL to all file format drivers and all printer drivers.
# --with-x to use the X Window System.
# --without-omni to disable the outdated and unmaintained omni driver.
# --without-jasper and --enable-openjpeg because since Ghostscript 9.05 JasPer is deprecated
#   and Ghostscript now ships modified OpenJPEG sources for JPEG2000 decoding
#   (replacing JasPer - although JasPer is still included for this release).
#   Performance, reliability and memory use whilst decoding JPX streams are all improved.
# --without-ufst and --without-luratech because those are relevant to commercial releases only
#   which would require a commercial license.
# --without-libpaper disables libpaper support because SUSE does not have libpaper.
%define gs_font_path /usr/share/fonts/truetype:/usr/share/fonts/Type1:/usr/share/fonts/CID:/usr/share/fonts/URW
# See http://bugs.ghostscript.com/show_bug.cgi?id=693100
export SUSE_ASNEEDED=0
./configure --prefix=%{_prefix} \
            --bindir=%{_bindir} \
            --libdir=%{_libdir} \
            --datadir=%{_datadir} \
            --mandir=%{_mandir} \
            --infodir=%{_infodir} \
            --with-fontpath=%{gs_font_path} \
            --with-libiconv=maybe \
            --enable-freetype \
            --with-jbig2dec \
            --without-jasper \
            --enable-openjpeg \
            --enable-dynamic \
            --with-ijs \
            --enable-cups \
            --enable-dbus \
            --with-pdftoraster \
            --with-install-cups \
            --with-drivers=ALL \
            --with-x \
            --disable-gtk \
            --disable-compile-inits \
            --without-omni \
            --without-ufst \
            --without-luratech \
            --without-libpaper
make
# Make libgs.so and two programs which use it, gsx and gsc:
make so
# Configure and make libijs (that is not done regardless whether or not --with-ijs is used above):
pushd ijs
./autogen.sh
./configure --prefix=%{_prefix} \
            --bindir=%{_bindir} \
            --libdir=%{_libdir} \
            --datadir=%{_datadir} \
            --mandir=%{_mandir} \
            --infodir=%{_infodir} \
            --enable-shared \
            --disable-static
make
popd

%install
make install DESTDIR=%{buildroot}
# Install libgs.so gsx gsc and some header files:
make soinstall DESTDIR=%{buildroot}
# Install libijs and its header files:
pushd ijs
make install DESTDIR=%{buildroot}
popd
# Remove installed ijs example client and server and its .la file:
rm %{buildroot}%{_bindir}/ijs_client_example
rm %{buildroot}%{_bindir}/ijs_server_example
rm %{buildroot}%{_libdir}/libijs.la
# Install documentation which is not installed by default
# see http://bugs.ghostscript.com/show_bug.cgi?id=693002
# and fail intentionally as notification if something changed:
DOCDIR=%{buildroot}%{_datadir}/ghostscript/%{built_version}/doc
for D in LICENSE
do test -e $DOCDIR/$( basename $D ) && exit 99
   install -m 644 $D $DOCDIR
done
# Add a link from SUSE's usual documentation directory to Ghostscript's documentation directory
# because "configure --docdir=%%{_defaultdocdir}/%%{name}" does not work (see above):
install -d -m 755 %{buildroot}%{_defaultdocdir}
pushd %{buildroot}%{_defaultdocdir}
ln -s ../../ghostscript/%{built_version}/doc ghostscript
popd
# Extract the catalog of devices which are actually built-in in exactly this Ghostscript:
# Do not pollute the build log file with zillions of meaningless messages:
set +x
cat /dev/null >catalog.devices
for D in $( %{buildroot}/usr/bin/gs -h | sed -n -e '/^Available devices:/,/^Search path:/p' | egrep -v '^Available devices:|^Search path:' )
do for F in base/devs.mak base/contrib.mak contrib/contrib.mak
   do sed -n -e '/ Catalog /,/ End of catalog /p' $F | grep "[[:space:]]$D[[:space:]]" | grep -o '[[:alnum:]].*' | tr -s '[:blank:]' ' ' | sed -e 's/ /\t/' | expand -t16 >>catalog.devices
   done
done
# Switch back to the usual build log messages:
set -x
install -m 644 catalog.devices $DOCDIR

# Use traditional bash scriptlet with an explicite "exit 0" line at the end to be fail safe
# see http://en.opensuse.org/openSUSE:Packaging_scriptlet_snippets
%post
/sbin/ldconfig
exit 0

# Use traditional bash scriptlet with an explicite "exit 0" line at the end to be fail safe
# see http://en.opensuse.org/openSUSE:Packaging_scriptlet_snippets
%postun
/sbin/ldconfig
exit 0

%files
%defattr(-, root, root)
%{_bindir}/dvipdf
%{_bindir}/eps2eps
%{_bindir}/font2c
%{_bindir}/gs
%{_bindir}/gsx
%{_bindir}/gsc
%{_bindir}/gsbj
%{_bindir}/gsdj
%{_bindir}/gsdj500
%{_bindir}/gslj
%{_bindir}/gslp
%{_bindir}/gsnd
%{_bindir}/lprsetup.sh
%{_bindir}/pdf2dsc
%{_bindir}/pdf2ps
%{_bindir}/pf2afm
%{_bindir}/pfbtopfa
%{_bindir}/pphs
%{_bindir}/printafm
%{_bindir}/ps2ascii
%{_bindir}/ps2epsi
%{_bindir}/ps2pdf
%{_bindir}/ps2pdf12
%{_bindir}/ps2pdf13
%{_bindir}/ps2pdf14
%{_bindir}/ps2pdfwr
%{_bindir}/ps2ps
%{_bindir}/ps2ps2
%{_bindir}/unix-lpr.sh
%{_bindir}/wftopfa
%doc %{_mandir}/man1/dvipdf.1.gz
%doc %{_mandir}/man1/eps2eps.1.gz
%doc %{_mandir}/man1/font2c.1.gz
%doc %{_mandir}/man1/gs.1.gz
%doc %{_mandir}/man1/gsbj.1.gz
%doc %{_mandir}/man1/gsdj.1.gz
%doc %{_mandir}/man1/gsdj500.1.gz
%doc %{_mandir}/man1/gslj.1.gz
%doc %{_mandir}/man1/gslp.1.gz
%doc %{_mandir}/man1/gsnd.1.gz
%doc %{_mandir}/man1/pdf2dsc.1.gz
%doc %{_mandir}/man1/pdf2ps.1.gz
%doc %{_mandir}/man1/pf2afm.1.gz
%doc %{_mandir}/man1/pfbtopfa.1.gz
%doc %{_mandir}/man1/printafm.1.gz
%doc %{_mandir}/man1/ps2ascii.1.gz
%doc %{_mandir}/man1/ps2epsi.1.gz
%doc %{_mandir}/man1/ps2pdf.1.gz
%doc %{_mandir}/man1/ps2pdf12.1.gz
%doc %{_mandir}/man1/ps2pdf13.1.gz
%doc %{_mandir}/man1/ps2pdf14.1.gz
%doc %{_mandir}/man1/ps2pdfwr.1.gz
%doc %{_mandir}/man1/ps2ps.1.gz
%doc %{_mandir}/man1/wftopfa.1.gz
%doc %{_mandir}/man1/ijs-config.1.gz
%doc %{_mandir}/de/man1/dvipdf.1.gz
%doc %{_mandir}/de/man1/eps2eps.1.gz
%doc %{_mandir}/de/man1/font2c.1.gz
%doc %{_mandir}/de/man1/gsnd.1.gz
%doc %{_mandir}/de/man1/pdf2dsc.1.gz
%doc %{_mandir}/de/man1/pdf2ps.1.gz
%doc %{_mandir}/de/man1/printafm.1.gz
%doc %{_mandir}/de/man1/ps2ascii.1.gz
%doc %{_mandir}/de/man1/ps2pdf.1.gz
%doc %{_mandir}/de/man1/ps2pdf12.1.gz
%doc %{_mandir}/de/man1/ps2pdf13.1.gz
%doc %{_mandir}/de/man1/ps2pdf14.1.gz
%doc %{_mandir}/de/man1/ps2ps.1.gz
%doc %{_mandir}/de/man1/wftopfa.1.gz
%doc %{_defaultdocdir}/ghostscript
%dir %{_datadir}/ghostscript
%dir %{_datadir}/ghostscript/%{built_version}
%doc %{_datadir}/ghostscript/%{built_version}/doc/
%{_datadir}/ghostscript/%{built_version}/examples/
%{_datadir}/ghostscript/%{built_version}/iccprofiles/
%{_datadir}/ghostscript/%{built_version}/lib/
%{_datadir}/ghostscript/%{built_version}/Resource/
%{_libdir}/libgs.so.*
%{_libdir}/ghostscript/
%{_libdir}/libijs-0.35.so
%exclude %{_libdir}/ghostscript/%{built_version}/X11.so

%files x11
%defattr(-,root,root)
%{_libdir}/ghostscript/%{built_version}/X11.so

%files devel
%defattr(-,root,root)
%{_includedir}/ghostscript/
%{_libdir}/libgs.so
%{_bindir}/ijs-config
%{_includedir}/ijs/
%{_libdir}/libijs.so
%{_libdir}/pkgconfig/ijs.pc

%changelog
* Wed May  2 2018 jsmeix@suse.de
- CVE-2018-10194.patch fixes stack-based buffer overflow
  in gdevpdts.c (bsc#1090099), see
  https://bugs.ghostscript.com/show_bug.cgi?id=699255 and
  http://git.ghostscript.com/?p=ghostpdl.git;a=commit;h=39b1e54b2968620723bf32e96764c88797714879
* Mon Jan 22 2018 daniel.molkentin@suse.com
- Update CVE-2016-10317.patch to final upstream patch,
  required another commit which has been sqashed in
- CVE-2017-9835.patch fixes heap-based buffer overflow in gs_alloc_ref_array
  see https://bugs.ghostscript.com/show_bug.cgi?id=697985
  (bsc#1050879)
* Fri Jan 19 2018 daniel.molkentin@suse.com
- CVE-2016-10317.patch fixes DoS in fill_threshhold_buffer
  see https://bugs.ghostscript.com/show_bug.cgi?id=697459
  (bsc#1032230)
- CVE-2017-9612.patch fixes DoS in Ins_IP function
  see https://bugs.ghostscript.com/show_bug.cgi?id=698026
  (bsc#1050891)
- CVE-2017-9726.patch fixes heap-based buffer over-read in Ins_MDRP
  see http://bugs.ghostscript.com/show_bug.cgi?id=698055
  (bsc#1050889)
- CVE-2017-9727.patch fixes DoS in gx_ttfReader__Read function
  see http://bugs.ghostscript.com/show_bug.cgi?id=698056
  (bsc#1050888)
- CVE-2017-9739.patch fixes DoS in Ins_JMPR function
  see https://bugs.ghostscript.com/show_bug.cgi?id=698063
  (bsc#1050887)
- CVE-2017-11714.patch fixes out of bounds read in igc_reloc_struct_ptr()
  (bsc#1051184)
- CVE-2016-10219.patch fixes DoS in intersect() function
  see https://bugs.ghostscript.com/show_bug.cgi?id=697453
  (bsc#1032138)
* Fri Jun  2 2017 daniel.molkentin@suse.com
- CVE-2017-9216.patch fixes a NULL pointer dereference in jbig2_huffman_get
  see https://bugs.ghostscript.com/show_bug.cgi?id=697934
  (bsc#1040643)
* Fri Apr 28 2017 vcizek@suse.com
- CVE-2016-9601.patch fixes an integer overflow in jbig2_image_new
  see https://bugs.ghostscript.com/show_bug.cgi?id=697457
  (bsc#1018128)
- CVE-2016-10220.patch fixes a NULL pointer dereference in gx_device_finalize
  see https://bugs.ghostscript.com/show_bug.cgi?id=697450
  (bsc#1032120)
- CVE-2017-5951.patch fixes a NULL pointer dereference in ref_stack_index
  see https://bugs.ghostscript.com/show_bug.cgi?id=697548
  (bsc#1032114)
- CVE-2017-7207.patch fixes a NULL pointer dereference in mem_get_bits_rectangle
  see https://bugs.ghostscript.com/show_bug.cgi?id=697676
  (bsc#1030263)
* Fri Apr 28 2017 vcizek@suse.com
- CVE-2017-8291.patch fixes a type confusion in .rsdparams and .eqproc
  see https://bugs.ghostscript.com/show_bug.cgi?id=697808
  (bsc#1036453)
* Tue Nov  1 2016 alarrosa@suse.com
- Add 0001-Fix-locksafe.patch to fix a regression introduced
  in CVE-2013-5653.patch by which ps files couldn't be opened
  in okular/evince (boo#1006592, kde#371887).
* Thu Oct 20 2016 jsmeix@suse.de
- CVE-2016-8602.patch fixes a NULL dereference in .sethalftone5
  see http://bugs.ghostscript.com/show_bug.cgi?id=697203
  (bsc#1004237).
* Mon Oct 10 2016 sflees@suse.de
- Fix multiple -dsafer realated CVE's (bsc#1001951)
  * CVE-2013-5653.patch
  * CVE-2016-7978.patch
  * CVE-2016-7979.patch
* Fri Jan 29 2016 fcrozat@suse.com
- Add fix-mutex-crash.patch: fix crash in mutex (bsc#963017)
  (ghostscript bug #695862)
* Mon Jul 27 2015 jsmeix@suse.de
- CVE-2015-3228.patch fixes out of bound read/write cause
  by integer overflow in gsmalloc.c (boo#939342).
* Sun Sep 28 2014 ro@suse.de
- readd ppc64le patch ppc64le-support.patch
  lcms has not been fixed upstream and lcms2 has been fixed
  in a broken way
* Tue Sep 23 2014 jsmeix@suse.de
- Version upgrade to 9.15. Primarily a maintenance release.
  There are no recorded incompatible changes (as of this writing).
  Highlights in this release include:
  * Ghostscript now supports the PDF security handler revision 6.
  * The pdfwrite and ps2write (and related) devices can now be
    forced to "flatten" glyphs into "basic" marking operations
    (rather than writing fonts to the output), by giving
    the -dNoOutputFonts command line option (defaults to "false").
  * PostScript programs can now use get_params or get_param to
    determine if a page contains color markings by reading the
    pageneutralcolor state from the device (so whether the page
    is "color" or "mono"). Note that this is only accurate when in
    clist mode, so -dMaxBitmap=0 and -dGrayDetection=true should
    both be used.
  * The pdfwrite device now supports Link annotations with GoTo
    and GoToR actions.
  * The pdfwrite device now supports BMC/BDC/EMC pdfmarks
  * Regarding the new color management for the pdfwrite device
    introduced in the previous release, the proscription on using
    the new color management when producing PDF/A-1 compliant files
    is now lifted. To reiterate, also, with the new color
    management implementation, using the UseCIEColor option is
    strongly discouraged. For further information on the new
    pdfwrite color management, see in Ps2pdf.htm the
    "Color Conversion and Management" section.
  * Plus the usual round of bug fixes, compatibility changes,
    and incremental improvements.
  For details see the News.htm and History9.htm files.
* Wed Sep 17 2014 jsmeix@suse.de
- Version upgrade to 9.15rc2 (second release candidate for 9.15).
  Ghostscript upstream QA highlighted a couple of issues
  that they felt warranted a fresh release candidate.
  For details see the History9.htm file.
* Tue Sep  9 2014 jsmeix@suse.de
- Version upgrade to 9.15rc1 (first release candidate for 9.15).
  For details see the News.htm and History9.htm files.
- ppc64le-support.patch is no longer needed because
  it is fixed in the upstream sources.
- Removed trailing whitespaces in spec file and changes file.
* Mon Aug 18 2014 meissner@suse.com
- gs does not seem to require libopenssl-devel for building.
* Thu Mar 27 2014 jsmeix@suse.de
- Version upgrade to 9.14. Primarily a maintenance release.
  Highlights in this release include (excerpt):
  * pdfwrite now uses the same color management engine as
    Ghostscript rendering devices (by default LCMS2). For
    the duration of this release a new switch -dPDFUseOldCMS
    is available which will restore the old color management.
    See: "Color Conversion and Management" in Ps2pdf.htm
    Due to constraints of the PDF/A-1 specification, the new color
    management does not yet apply when producing PDF/A files.
  * A new device 'eps2write' has been added which allows for the
    creation of EPS files using the ps2write device instead of
    the deprecated and removed pswrite device. The epswrite device
    is now also deprecated and will be removed in a future release.
  * Ghostscript has a new "pwgraster" output device for PWG Raster
    output.
  * The CUPS device now has improved support for PPD-less printing.
  For details see the News.htm and History9.htm files.
* Fri Dec 13 2013 uweigand@de.ibm.com
- ppc64le-support.patch from IBM fixes endianness
  in lcms (the Little-CMS library) to support the new
  architecture ppc64le (IBM Power PC Little Endian architecture)
  because ppc64 is big-endian and ppc64le is little-endian
  and lcms has a hard-coded check that assumes PowerPC
  is always big-endian which is incorrect on ppc64le.
  The fix is already in the main Little-CMS repository
  by this Git commit
  https://github.com/mm2/Little-CMS/commit/b4f5c91a2c1582bd284f0d0f49cb43e2c2235a79
  (There are some cosmetic changes in the upstream patch.)
  It is not yet in the imported copy in Ghostscript.
  IBM will work with upstream to get the fix imported too.
* Tue Sep  3 2013 jsmeix@suse.de
- Version upgrade to 9.10. Primarily a maintenance release.
  Highlights in this release include:
  * LittleCMS2 and libpng have both been updated to the
    latest versions.
  * The URW Postscript font set has been updated to the
    latest version, fixing many compatibility problems
    with the Adobe fonts.
  * The CUPS filters gstoraster and gstopxl have been
    removed from Ghostscript. Those filters are now provided by
    cups-filters (a free software package hosted by OpenPrinting)
    that contains all CUPS filters needed by CUPS under Linux
    (see also the openSUSE issue bnc#735404 comment#44 at
    https://bugzilla.novell.com/show_bug.cgi?id=735404#c44).
  For details see the News.htm and History9.htm files.
- fix-undefined-operation.patch is no longer needed because
  it is fixed in the upstream sources.
* Thu Aug 29 2013 jsmeix@suse.de
- Version upgrade to 9.10rc1 (release candidate for the 9.10 version).
  For details see the News.htm and History9.htm files.
- Prepare spec files to build both releases and release candidates
  easily in the future by using special different version strings.
- fix-undefined-operation.patch fixes
  http://bugs.ghostscript.com/show_bug.cgi?id=694546
- Removed BuildRequires for liblcms-devel because it is not needed
  when we build Ghostscript that works in compliance with upstream
  (see https://bugzilla.novell.com/show_bug.cgi?id=828751#c5).
* Wed Mar 27 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Feb 19 2013 jsmeix@suse.de
- Version upgrade to 9.07.
  * As of this release (9.07), Ghostscript is distributed
    under the GNU Affero General Public License (AGPL).
  * Ghostscript has been extended to support file sizes >4Gb
    in particular reading and writing PDF files.
  * Color management enhancements. Full details of the color
    management features can be found in: GS9_Color_Management.pdf
  * The pdfwrite devices now supports linearized (or optimized
    for fast web view) output directly ("-dFastWebView").
  * With the addition of linearisation to pdfwrite, pdfopt.ps
    has become redundant. Since it is difficult to maintain,
    has a number of bugs, and is believed not to work properly
    anyway, it is removed. Accordingly the pdfopt shell script
    that used pdfopt.ps is also removed.
* Thu Jan  3 2013 jsmeix@suse.de
- Provide libijs (that is not done via "configure --with-ijs")
  because libijs is needed by the pdftoijs filter in the
  cups-filters package (see the README file in cups-filters).
* Thu Sep 27 2012 mmeister@suse.com
- Version upgrade to 9.06. Mainly a bugfix release.
  * pdfwrite announcements:
    pdfwrite now supports the creation of PDF/A-2 files.
    For further details see the NEWS file.
  * removed moribund dumphint tool, see History9.htm and
    http://bugs.ghostscript.com/show_bug.cgi?id=693223
* Mon Sep 24 2012 idonmez@suse.com
- "export SUSE_ASNEEDED=0" disables -Wl,--as-needed linker flags,
  see http://bugs.ghostscript.com/show_bug.cgi?id=693100
* Thu May 10 2012 jsmeix@suse.de
- Require Ghostscript's font packages because the
  Ghostscript package provides the "Fontmap" file
  /usr/share/ghostscript/<version>/Resource/Init/Fontmap.GS
  which lists Ghostscript's fonts but the fonts itself
  are provided in the separated packages ghostscript-fonts-std
  and ghostscript-fonts-other so that a RPM requirement
  is needed to make sure that Ghostscript has its fonts.
- Extract the catalog of devices which are actually built-in
  in exactly this Ghostscript and provide it as catalog.devices
  in the Ghostscript package.
* Fri Apr 27 2012 jsmeix@suse.de
- BuildRequires dbus-1-devel for "configure --enable-dbus"
  to have colord support in gstoraster (see the entry regarding
  "color management daemon" in doc/History9.htm).
* Tue Apr 24 2012 jsmeix@suse.de
- Install documentation which is not installed by default
  (LICENSE doc/AUTHORS doc/COPYING doc/thirdparty.htm
  doc/WhatIsGS.htm doc/GS9_Color_Management.pdf
  doc/gs-vms.hlp doc/Ps2ps2.htm).
- Add a link from SUSE's usual documentation directory
  (/usr/share/doc/packages/ghostscript/) to Ghostscript's
  documentation directory (/usr/share/ghostscript/9.05/doc/)
  because "configure --docdir=..." does not work.
* Thu Apr  5 2012 jsmeix@suse.de
- Removed BuildRequires docbook-toys which is not needed
  (db2ps and db2pdf called in ijs/Makefile.am to make ijs_spec.ps
  and ijs_spec.pdf but neither of them is made - both are
  provided in the sources) but docbook-toys pulls in packages
  like texlive-bin-jadetex and texlive-jadetex which needlessly
  blow up the build system.
* Wed Mar 28 2012 jsmeix@suse.de
- Require the basic fonts for Ghostscript
  (package ghostscript-fonts-std) and recommend the
  optional fonts (package ghostscript-fonts-other).
* Fri Mar 23 2012 jsmeix@suse.de
- Cleaned up BuildRequires.
- Added ghostscript-mini.spec with minimal BuildRequires.
- Explicitly specify configure --with-* versus --without-*
  in ghostscript.spec versus ghostscript-mini.spec
  to make the differences clear.
* Fri Mar 16 2012 jsmeix@suse.de
- Unfortunately ghostscript-library.spec and ghostscript-mini.spec
  have unversioned "Provides: ghostscript" and for RPM this means
  that both ghostscript-library and ghostscript-mini
  provide any version of ghostscript. Therefore any non-matching
  version of ghostscript-library and ghostscript-mini fulfill
  any RPM requirement for ghostscript in the ghostscript-x11
  and ghostscript-devel sub-packages which is wrong.
  Therefore explicit conflicts with ghostscript-library and
  ghostscript-mini are specified in the ghostscript-x11
  and ghostscript-devel sub-packages to avoid the mess.
* Thu Mar 15 2012 jsmeix@suse.de
- Configure --without-libpaper disables libpaper support
  because SUSE does not have libpaper.
* Thu Mar 15 2012 jsmeix@suse.de
- Configure --without-jasper and --enable-openjpeg because
  since Ghostscript 9.05 JasPer is deprecated and Ghostscript
  now ships modified OpenJPEG sources for JPEG2000 decoding
  (replacing JasPer). Performance, reliability and memory use
  whilst decoding JPX streams are all improved. Accordingly
  the BuildRequires libjasper-devel is removed.
- Configure --without-ufst and --without-luratech because
  those are relevant to commercial releases only
  which would require a commercial license.
- Added BuildRequires libtool which requires automake and
  automake requires autoconf to fix build requirements
  for openSUSE:Factory.
* Fri Feb 24 2012 jsmeix@suse.de
- Using fixed /usr/lib/cups/filter (no lib64) because CUPS
  in the Printing project uses it in any case.
* Fri Feb 24 2012 jsmeix@suse.de
- Adapt RPM dependencies to what is actually used
  in openSUSE:Factory (dated 22 Feb. 2012).
* Thu Feb 16 2012 jsmeix@suse.de
- Added RPM dependencies to make sure ghostscript-x11 and the
  main-package have exact matching version-release because both
  could have any kind of Ghostscript-internal dependencies.
  This is only an approximation to have ghostscript-x11 and
  the main-package from the same build where the main-package
  and its sub-package have been made but currently there is
  no clean way to specify a 'same build' RPM dependency.
  Therefore currently ghostscript-x11 and the main-package could
  have same version-release but nevertheless come from different
  projects/repositories (e.g. with different patches or
  whatever kind of differences).
* Wed Feb 15 2012 jsmeix@suse.de
- Split files which require X11 stuff into a ghostscript-x11
  sub-package (currently only /usr/lib/ghostscript/9.05/X11.so)
  so that the ghostscript package can be installed without X11.
* Thu Feb  9 2012 jsmeix@suse.de
- Upgrade to version 9.05 (see bnc#735824):
  New simple ink-coverage device (inkconv).
  The ps2write device has a large number of improvements.
  Fixes and improvements for the CUPS Raster output device
  (in particular Ghostscript bug 691922 regarding color model).
  Renamed the PXL CUPS filter from "pstopxl" to "gstopxl".
  For details see the doc/News.htm file.
- Removed "make cups" and "make cups-install" from spec file
  using "configure ... --with-install-cups" instead
  (new since version 9.04, see "configure --help").
* Tue Dec 13 2011 jw@suse.com
- Upgrade to version 9.04 (see bnc#735824):
  For details see the doc/News.htm file.
- Added "make cups" and "make cups-install" to spec file.
* Tue Mar 15 2011 jsmeix@suse.de
- Initial ghostscript package.
